types

package
v0.0.0-...-b89ff6f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 15, 2024 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type TypeInstance

type TypeInstance struct {
	Value any
	Tags  []string
}

type Types

type Types struct{}

func (Types) AllKinds

func (t Types) AllKinds() []string

Return all kinds.

func (Types) AllTypeInstances

func (t Types) AllTypeInstances() []any

Return all type instances, excluding the kinds given.

func (Types) BasicInstances

func (t Types) BasicInstances() []any

Return instances of basic types.

func (Types) BasicKinds

func (t Types) BasicKinds() []string

Return kinds of basic types.

func (Types) ComparableInstances

func (t Types) ComparableInstances() []any

Return instances of comparable types.

func (Types) ComparableKinds

func (t Types) ComparableKinds() []string

Return kinds of comparable types.

func (Types) ElementInstances

func (t Types) ElementInstances() []any

Return instances of element types.

func (Types) ElementKinds

func (t Types) ElementKinds() []string

Return kinds of element types.

func (Types) Instances

func (t Types) Instances(includeTags []string, excludeKinds []string) []any

Return a filtered list of instances inclusively by the tags given,

then exclusively by specific kinds given.

func (Types) IntegerInstances

func (t Types) IntegerInstances() []any

Return instances of integer types.

func (Types) IntegerKinds

func (t Types) IntegerKinds() []string

Return kinds of integer types.

func (Types) KeyInstances

func (t Types) KeyInstances() []any

Return instances of key types, identical to comparable types.

func (Types) KeyKinds

func (t Types) KeyKinds() []string

Return kinds of key types.

func (Types) Kinds

func (t Types) Kinds(includeTags []string, exclude []string) []string

Return a filtered list of kinds inclusively by the tags given,

then exclusively by specific kinds given.

func (Types) MapInstances

func (t Types) MapInstances() []any

Return instances of map types.

func (Types) NumbericInstances

func (t Types) NumbericInstances() []any

Return instances of numeric types.

func (Types) NumbericKinds

func (t Types) NumbericKinds() []string

Return kinds of numeric types.

func (Types) OrderedInstances

func (t Types) OrderedInstances() []any

Return instances of ordered types.

func (Types) OrderedKinds

func (t Types) OrderedKinds() []string

Return kinds of ordered types.

func (Types) SliceInstances

func (t Types) SliceInstances() []any

Return instances of slice types.

Jump to