Documentation
¶
Index ¶
- type TypeInstance
- type Types
- func (t Types) AllKinds() []string
- func (t Types) AllTypeInstances() []any
- func (t Types) BasicInstances() []any
- func (t Types) BasicKinds() []string
- func (t Types) ComparableInstances() []any
- func (t Types) ComparableKinds() []string
- func (t Types) ElementInstances() []any
- func (t Types) ElementKinds() []string
- func (t Types) Instances(includeTags []string, excludeKinds []string) []any
- func (t Types) IntegerInstances() []any
- func (t Types) IntegerKinds() []string
- func (t Types) KeyInstances() []any
- func (t Types) KeyKinds() []string
- func (t Types) Kinds(includeTags []string, exclude []string) []string
- func (t Types) MapInstances() []any
- func (t Types) NumbericInstances() []any
- func (t Types) NumbericKinds() []string
- func (t Types) OrderedInstances() []any
- func (t Types) OrderedKinds() []string
- func (t Types) SliceInstances() []any
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type TypeInstance ¶
type Types ¶
type Types struct{}
func (Types) AllTypeInstances ¶
Return all type instances, excluding the kinds given.
func (Types) BasicInstances ¶
Return instances of basic types.
func (Types) ComparableInstances ¶
Return instances of comparable types.
func (Types) ComparableKinds ¶
Return kinds of comparable types.
func (Types) ElementInstances ¶
Return instances of element types.
func (Types) Instances ¶
Return a filtered list of instances inclusively by the tags given,
then exclusively by specific kinds given.
func (Types) IntegerInstances ¶
Return instances of integer types.
func (Types) KeyInstances ¶
Return instances of key types, identical to comparable types.
func (Types) Kinds ¶
Return a filtered list of kinds inclusively by the tags given,
then exclusively by specific kinds given.
func (Types) NumbericInstances ¶
Return instances of numeric types.
func (Types) OrderedInstances ¶
Return instances of ordered types.
func (Types) SliceInstances ¶
Return instances of slice types.
Click to show internal directories.
Click to hide internal directories.